==> kdeaddons-3.0.1.tar.bz2: kdeaddons-3.0.1/noatun-plugins/jefferson/jefferson.h <==
// Copyright (c) 2001 Neil Stevens <multivac@fcmail.com>
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
// AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
// AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
// CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

#ifndef JEFFERSON_H
#define JEFFERSON_H

#include <noatun/plugin.h>
#include <qcolor.h>
#include <qdatetime.h>
#include <qfont.h>
#include <qobject.h>
#include "kosd.h"

class Jefferson : public QObject, public Plugin
{
Q_OBJECT

public:
	Jefferson(void);
	virtual ~Jefferson(void);

	virtual void init(void);

	void setFont(QFont);
	void setColor(QColor);
	void setPosition(KOSD::Position);
public:
	static Jefferson *tommy;

protected slots:
	void newSong(void);
	void playing(void);
	void paused(void);
	void stopped(void);

private:
	KOSD osd;
	QDateTime time;
};

#endif

==> kdeaddons-3.1.tar.bz2: kdeaddons-3.1/noatun-plugins/jefferson/jefferson.h <==
// Copyright (c) 2001 Neil Stevens <multivac@fcmail.com>
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
// AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
// AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
// CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

#ifndef JEFFERSON_H
#define JEFFERSON_H

#include <noatun/plugin.h>
#include <qcolor.h>
#include <qdatetime.h>
#include <qfont.h>
#include <qobject.h>
#include "kosd.h"

class Jefferson : public QObject, public Plugin
{
Q_OBJECT

public:
	Jefferson(void);
	virtual ~Jefferson(void);

	virtual void init(void);

	void setFont(QFont);
	void setColor(QColor);
	void setPosition(int);
	void setTimeout(u_int);
public:
	static Jefferson *tommy;

protected slots:
	void newSong(void);
	void playing(void);
	void paused(void);
	void stopped(void);

private:
	KOSD osd;
	QDateTime time;
};

#endif
